Class: Aws::ServiceQuotas::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ServiceQuotas::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-servicequotas/client.rb,
sig/client.rbs
Overview
An API client for ServiceQuotas. To construct a client, you need to configure a :region and :credentials.
client = Aws::ServiceQuotas::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateServiceQuotaTemplateResponseSuccess, _CreateSupportCaseResponseSuccess, _DeleteServiceQuotaIncreaseRequestFromTemplateResponseSuccess, _DisassociateServiceQuotaTemplateResponseSuccess, _GetAWSDefaultServiceQuotaResponseSuccess, _GetAssociationForServiceQuotaTemplateResponseSuccess, _GetAutoManagementConfigurationResponseSuccess, _GetQuotaUtilizationReportResponseSuccess, _GetRequestedServiceQuotaChangeResponseSuccess, _GetServiceQuotaIncreaseRequestFromTemplateResponseSuccess, _GetServiceQuotaResponseSuccess, _ListAWSDefaultServiceQuotasResponseSuccess, _ListRequestedServiceQuotaChangeHistoryByQuotaResponseSuccess, _ListRequestedServiceQuotaChangeHistoryResponseSuccess, _ListServiceQuotaIncreaseRequestsInTemplateResponseSuccess, _ListServiceQuotasResponseSuccess, _ListServicesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutServiceQuotaIncreaseRequestIntoTemplateResponseSuccess, _RequestServiceQuotaIncreaseResponseSuccess, _StartAutoManagementResponseSuccess, _StartQuotaUtilizationReportResponseSuccess, _StopAutoManagementResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAutoManagementResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_service_quota_template(params = {}) ⇒ Struct
Associates your quota request template with your organization.
-
#create_support_case(params = {}) ⇒ Struct
Creates a Support case for an existing quota increase request.
-
#delete_service_quota_increase_request_from_template(params = {}) ⇒ Struct
Deletes the quota increase request for the specified quota from your quota request template.
-
#disassociate_service_quota_template(params = {}) ⇒ Struct
Disables your quota request template.
-
#get_association_for_service_quota_template(params = {}) ⇒ Types::GetAssociationForServiceQuotaTemplateResponse
Retrieves the status of the association for the quota request template.
-
#get_auto_management_configuration(params = {}) ⇒ Types::GetAutoManagementConfigurationResponse
Retrieves information about your [Service Quotas Automatic Management][1] configuration.
-
#get_aws_default_service_quota(params = {}) ⇒ Types::GetAWSDefaultServiceQuotaResponse
Retrieves the default value for the specified quota.
-
#get_quota_utilization_report(params = {}) ⇒ Types::GetQuotaUtilizationReportResponse
Retrieves the quota utilization report for your Amazon Web Services account.
-
#get_requested_service_quota_change(params = {}) ⇒ Types::GetRequestedServiceQuotaChangeResponse
Retrieves information about the specified quota increase request.
-
#get_service_quota(params = {}) ⇒ Types::GetServiceQuotaResponse
Retrieves the applied quota value for the specified account-level or resource-level quota.
-
#get_service_quota_increase_request_from_template(params = {}) ⇒ Types::GetServiceQuotaIncreaseRequestFromTemplateResponse
Retrieves information about the specified quota increase request in your quota request template.
-
#list_aws_default_service_quotas(params = {}) ⇒ Types::ListAWSDefaultServiceQuotasResponse
Lists the default values for the quotas for the specified Amazon Web Services service.
-
#list_requested_service_quota_change_history(params = {}) ⇒ Types::ListRequestedServiceQuotaChangeHistoryResponse
Retrieves the quota increase requests for the specified Amazon Web Services service.
-
#list_requested_service_quota_change_history_by_quota(params = {}) ⇒ Types::ListRequestedServiceQuotaChangeHistoryByQuotaResponse
Retrieves the quota increase requests for the specified quota.
-
#list_service_quota_increase_requests_in_template(params = {}) ⇒ Types::ListServiceQuotaIncreaseRequestsInTemplateResponse
Lists the quota increase requests in the specified quota request template.
-
#list_service_quotas(params = {}) ⇒ Types::ListServiceQuotasResponse
Lists the applied quota values for the specified Amazon Web Services service.
-
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists the names and codes for the Amazon Web Services services integrated with Service Quotas.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags assigned to the specified applied quota.
-
#put_service_quota_increase_request_into_template(params = {}) ⇒ Types::PutServiceQuotaIncreaseRequestIntoTemplateResponse
Adds a quota increase request to your quota request template.
-
#request_service_quota_increase(params = {}) ⇒ Types::RequestServiceQuotaIncreaseResponse
Submits a quota increase request for the specified quota at the account or resource level.
-
#start_auto_management(params = {}) ⇒ Struct
Starts [Service Quotas Automatic Management][1] for an Amazon Web Services account, including notification preferences and excluded quotas configurations.
-
#start_quota_utilization_report(params = {}) ⇒ Types::StartQuotaUtilizationReportResponse
Initiates the generation of a quota utilization report for your Amazon Web Services account.
-
#stop_auto_management(params = {}) ⇒ Struct
Stops [Service Quotas Automatic Management][1] for an Amazon Web Services account and removes all associated configurations.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified applied quota.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified applied quota.
-
#update_auto_management(params = {}) ⇒ Struct
Updates your [Service Quotas Automatic Management][1] configuration, including notification preferences and excluded quotas.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1838 1839 1840 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1838 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1841 1842 1843 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1841 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_service_quota_template(params = {}) ⇒ Struct
Associates your quota request template with your organization. When a new Amazon Web Services account is created in your organization, the quota increase requests in the template are automatically applied to the account. You can add a quota increase request for any adjustable quota to your template.
86 |
# File 'sig/client.rbs', line 86
def associate_service_quota_template: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1811 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ServiceQuotas') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-servicequotas' context[:gem_version] = '1.75.0' Seahorse::Client::Request.new(handlers, context) end |
#create_support_case(params = {}) ⇒ Struct
Creates a Support case for an existing quota increase request. This
call only creates a Support case if the request has a Pending
status.
94 |
# File 'sig/client.rbs', line 94
def create_support_case: (
|
#delete_service_quota_increase_request_from_template(params = {}) ⇒ Struct
Deletes the quota increase request for the specified quota from your quota request template.
103 |
# File 'sig/client.rbs', line 103
def delete_service_quota_increase_request_from_template: (
|
#disassociate_service_quota_template(params = {}) ⇒ Struct
Disables your quota request template. After a template is disabled, the quota increase requests in the template are not applied to new Amazon Web Services accounts in your organization. Disabling a quota request template does not apply its quota increase requests.
114 |
# File 'sig/client.rbs', line 114
def disassociate_service_quota_template: (
|
#get_association_for_service_quota_template(params = {}) ⇒ Types::GetAssociationForServiceQuotaTemplateResponse
Retrieves the status of the association for the quota request template.
134 |
# File 'sig/client.rbs', line 134
def get_association_for_service_quota_template: (
|
#get_auto_management_configuration(params = {}) ⇒ Types::GetAutoManagementConfigurationResponse
Retrieves information about your Service Quotas Automatic Management configuration. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
147 |
# File 'sig/client.rbs', line 147
def get_auto_management_configuration: (
|
#get_aws_default_service_quota(params = {}) ⇒ Types::GetAWSDefaultServiceQuotaResponse
Retrieves the default value for the specified quota. The default value does not reflect any quota increases.
123 |
# File 'sig/client.rbs', line 123
def get_aws_default_service_quota: (
|
#get_quota_utilization_report(params = {}) ⇒ Types::GetQuotaUtilizationReportResponse
Retrieves the quota utilization report for your Amazon Web Services account. This operation returns paginated results showing your quota usage across all Amazon Web Services services, sorted by utilization percentage in descending order (highest utilization first).
You must first initiate a report using the
StartQuotaUtilizationReport operation. The report generation process
is asynchronous and may take several seconds to complete. Poll this
operation periodically to check the status and retrieve results when
the report is ready.
Each report contains up to 1,000 quota records per page. Use the
NextToken parameter to retrieve additional pages of results. Reports
are automatically deleted after 15 minutes.
163 |
# File 'sig/client.rbs', line 163
def get_quota_utilization_report: (
|
#get_requested_service_quota_change(params = {}) ⇒ Types::GetRequestedServiceQuotaChangeResponse
Retrieves information about the specified quota increase request.
175 |
# File 'sig/client.rbs', line 175
def get_requested_service_quota_change: (
|
#get_service_quota(params = {}) ⇒ Types::GetServiceQuotaResponse
Retrieves the applied quota value for the specified account-level or resource-level quota. For some quotas, only the default values are available. If the applied quota value is not available for a quota, the quota is not retrieved.
185 |
# File 'sig/client.rbs', line 185
def get_service_quota: (
|
#get_service_quota_increase_request_from_template(params = {}) ⇒ Types::GetServiceQuotaIncreaseRequestFromTemplateResponse
Retrieves information about the specified quota increase request in your quota request template.
197 |
# File 'sig/client.rbs', line 197
def get_service_quota_increase_request_from_template: (
|
#list_aws_default_service_quotas(params = {}) ⇒ Types::ListAWSDefaultServiceQuotasResponse
Lists the default values for the quotas for the specified Amazon Web Services service. A default value does not reflect any quota increases.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
210 |
# File 'sig/client.rbs', line 210
def list_aws_default_service_quotas: (
|
#list_requested_service_quota_change_history(params = {}) ⇒ Types::ListRequestedServiceQuotaChangeHistoryResponse
Retrieves the quota increase requests for the specified Amazon Web Services service. Filter responses to return quota requests at either the account level, resource level, or all levels. Responses include any open or closed requests within 90 days.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
223 |
# File 'sig/client.rbs', line 223
def list_requested_service_quota_change_history: (
|
#list_requested_service_quota_change_history_by_quota(params = {}) ⇒ Types::ListRequestedServiceQuotaChangeHistoryByQuotaResponse
Retrieves the quota increase requests for the specified quota. Filter responses to return quota requests at either the account level, resource level, or all levels.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
238 |
# File 'sig/client.rbs', line 238
def list_requested_service_quota_change_history_by_quota: (
|
#list_service_quota_increase_requests_in_template(params = {}) ⇒ Types::ListServiceQuotaIncreaseRequestsInTemplateResponse
Lists the quota increase requests in the specified quota request template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
254 |
# File 'sig/client.rbs', line 254
def list_service_quota_increase_requests_in_template: (
|
#list_service_quotas(params = {}) ⇒ Types::ListServiceQuotasResponse
Lists the applied quota values for the specified Amazon Web Services service. For some quotas, only the default values are available. If the applied quota value is not available for a quota, the quota is not retrieved. Filter responses to return applied quota values at either the account level, resource level, or all levels.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
268 |
# File 'sig/client.rbs', line 268
def list_service_quotas: (
|
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists the names and codes for the Amazon Web Services services integrated with Service Quotas.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
283 |
# File 'sig/client.rbs', line 283
def list_services: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags assigned to the specified applied quota.
294 |
# File 'sig/client.rbs', line 294
def list_tags_for_resource: (
|
#put_service_quota_increase_request_into_template(params = {}) ⇒ Types::PutServiceQuotaIncreaseRequestIntoTemplateResponse
Adds a quota increase request to your quota request template.
304 |
# File 'sig/client.rbs', line 304
def put_service_quota_increase_request_into_template: (
|
#request_service_quota_increase(params = {}) ⇒ Types::RequestServiceQuotaIncreaseResponse
Submits a quota increase request for the specified quota at the account or resource level.
317 |
# File 'sig/client.rbs', line 317
def request_service_quota_increase: (
|
#start_auto_management(params = {}) ⇒ Struct
Starts Service Quotas Automatic Management for an Amazon Web Services account, including notification preferences and excluded quotas configurations. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
330 |
# File 'sig/client.rbs', line 330
def start_auto_management: (
|
#start_quota_utilization_report(params = {}) ⇒ Types::StartQuotaUtilizationReportResponse
Initiates the generation of a quota utilization report for your Amazon Web Services account. This asynchronous operation analyzes your quota usage across all Amazon Web Services services and returns a unique report identifier that you can use to retrieve the results.
The report generation process may take several seconds to complete,
depending on the number of quotas in your account. Use the
GetQuotaUtilizationReport operation to check the status and retrieve
the results when the report is ready.
345 |
# File 'sig/client.rbs', line 345
def start_quota_utilization_report: (
|
#stop_auto_management(params = {}) ⇒ Struct
Stops Service Quotas Automatic Management for an Amazon Web Services account and removes all associated configurations. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
353 |
# File 'sig/client.rbs', line 353
def stop_auto_management: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified applied quota. You can include one or more tags to add to the quota.
361 |
# File 'sig/client.rbs', line 361
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified applied quota. You can specify one or more tags to remove.
376 |
# File 'sig/client.rbs', line 376
def untag_resource: (
|
#update_auto_management(params = {}) ⇒ Struct
Updates your Service Quotas Automatic Management configuration, including notification preferences and excluded quotas. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
386 |
# File 'sig/client.rbs', line 386
def update_auto_management: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1831 1832 1833 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1831 def waiter_names [] end |