Class: Aws::ServiceQuotas::Types::GetQuotaUtilizationReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-servicequotas/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return per page. The default value is 1,000 and the maximum allowed value is 1,000.

Returns:

  • (Integer)


274
275
276
277
278
279
280
# File 'lib/aws-sdk-servicequotas/types.rb', line 274

class GetQuotaUtilizationReportRequest < Struct.new(
  :report_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that indicates the next page of results to retrieve. This token is returned in the response when there are more results available. Omit this parameter for the first request.

Returns:

  • (String)


274
275
276
277
278
279
280
# File 'lib/aws-sdk-servicequotas/types.rb', line 274

class GetQuotaUtilizationReportRequest < Struct.new(
  :report_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#report_idString

The unique identifier for the quota utilization report. This identifier is returned by the ‘StartQuotaUtilizationReport` operation.

Returns:

  • (String)


274
275
276
277
278
279
280
# File 'lib/aws-sdk-servicequotas/types.rb', line 274

class GetQuotaUtilizationReportRequest < Struct.new(
  :report_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end