Class: Aws::ServiceQuotas::Types::ListRequestedServiceQuotaChangeHistoryByQuotaRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceQuotas::Types::ListRequestedServiceQuotaChangeHistoryByQuotaRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicequotas/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specifies the maximum number of results that you want included on each page of the response.
-
#next_token ⇒ String
Specifies a value for receiving additional results after you receive a ‘NextToken` response in a previous request.
-
#quota_code ⇒ String
Specifies the quota identifier.
-
#quota_requested_at_level ⇒ String
Filters the response to return quota requests for the ‘ACCOUNT`, `RESOURCE`, or `ALL` levels.
-
#service_code ⇒ String
Specifies the service identifier.
-
#status ⇒ String
Specifies that you want to filter the results to only the requests with the matching status.
Instance Attribute Details
#max_results ⇒ Integer
Specifies the maximum number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value appropriate to the operation. If additional items exist beyond those included in the current response, the ‘NextToken` response element is present and has a value (is not null). Include that value as the `NextToken` request parameter in the next call to the operation to get the next part of the results.
<note markdown=“1”> An API operation can return fewer results than the maximum even when there are more results available. You should check ‘NextToken` after every operation to ensure that you receive all of the results.
</note>
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 596 class ListRequestedServiceQuotaChangeHistoryByQuotaRequest < Struct.new( :service_code, :quota_code, :status, :next_token, :max_results, :quota_requested_at_level) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies a value for receiving additional results after you receive a ‘NextToken` response in a previous request. A `NextToken` response indicates that more output is available. Set this parameter to the value of the previous call’s ‘NextToken` response to indicate where the output should continue from.
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 596 class ListRequestedServiceQuotaChangeHistoryByQuotaRequest < Struct.new( :service_code, :quota_code, :status, :next_token, :max_results, :quota_requested_at_level) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
Specifies the quota identifier. To find the quota code for a specific quota, use the ListServiceQuotas operation, and look for the ‘QuotaCode` response in the output for the quota you want.
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 596 class ListRequestedServiceQuotaChangeHistoryByQuotaRequest < Struct.new( :service_code, :quota_code, :status, :next_token, :max_results, :quota_requested_at_level) SENSITIVE = [] include Aws::Structure end |
#quota_requested_at_level ⇒ String
Filters the response to return quota requests for the ‘ACCOUNT`, `RESOURCE`, or `ALL` levels. `ACCOUNT` is the default.
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 596 class ListRequestedServiceQuotaChangeHistoryByQuotaRequest < Struct.new( :service_code, :quota_code, :status, :next_token, :max_results, :quota_requested_at_level) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
Specifies the service identifier. To find the service code value for an Amazon Web Services service, use the ListServices operation.
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 596 class ListRequestedServiceQuotaChangeHistoryByQuotaRequest < Struct.new( :service_code, :quota_code, :status, :next_token, :max_results, :quota_requested_at_level) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Specifies that you want to filter the results to only the requests with the matching status.
596 597 598 599 600 601 602 603 604 605 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 596 class ListRequestedServiceQuotaChangeHistoryByQuotaRequest < Struct.new( :service_code, :quota_code, :status, :next_token, :max_results, :quota_requested_at_level) SENSITIVE = [] include Aws::Structure end |