Class: Aws::ServiceQuotas::Types::ListRequestedServiceQuotaChangeHistoryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceQuotas::Types::ListRequestedServiceQuotaChangeHistoryResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicequotas/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If present, indicates that more output is available than is included in the current response.
-
#requested_quotas ⇒ Array<Types::RequestedServiceQuotaChange>
Information about the quota increase requests.
Instance Attribute Details
#next_token ⇒ String
If present, indicates that more output is available than is included in the current response. Use this value in the ‘NextToken` request parameter in a subsequent call to the operation to get the next part of the output. You should repeat this until the `NextToken` response element comes back as `null`.
693 694 695 696 697 698 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 693 class ListRequestedServiceQuotaChangeHistoryResponse < Struct.new( :next_token, :requested_quotas) SENSITIVE = [] include Aws::Structure end |
#requested_quotas ⇒ Array<Types::RequestedServiceQuotaChange>
Information about the quota increase requests.
693 694 695 696 697 698 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 693 class ListRequestedServiceQuotaChangeHistoryResponse < Struct.new( :next_token, :requested_quotas) SENSITIVE = [] include Aws::Structure end |