Class: Aws::ServiceQuotas::Types::ListServiceQuotasRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-servicequotas/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

Specifies the maximum number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value appropriate to the operation. If additional items exist beyond those included in the current response, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results.

An API operation can return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.

Returns:

  • (Integer)


808
809
810
811
812
813
814
815
816
# File 'lib/aws-sdk-servicequotas/types.rb', line 808

class ListServiceQuotasRequest < Struct.new(
  :service_code,
  :next_token,
  :max_results,
  :quota_code,
  :quota_applied_at_level)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Specifies a value for receiving additional results after you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from.

Returns:

  • (String)


808
809
810
811
812
813
814
815
816
# File 'lib/aws-sdk-servicequotas/types.rb', line 808

class ListServiceQuotasRequest < Struct.new(
  :service_code,
  :next_token,
  :max_results,
  :quota_code,
  :quota_applied_at_level)
  SENSITIVE = []
  include Aws::Structure
end

#quota_applied_at_level ⇒ String

Filters the response to return applied quota values for the ACCOUNT, RESOURCE, or ALL levels. ACCOUNT is the default.

Returns:

  • (String)


808
809
810
811
812
813
814
815
816
# File 'lib/aws-sdk-servicequotas/types.rb', line 808

class ListServiceQuotasRequest < Struct.new(
  :service_code,
  :next_token,
  :max_results,
  :quota_code,
  :quota_applied_at_level)
  SENSITIVE = []
  include Aws::Structure
end

#quota_code ⇒ String

Specifies the quota identifier. To find the quota code for a specific quota, use the ListServiceQuotas operation, and look for the QuotaCode response in the output for the quota you want.

Returns:

  • (String)


808
809
810
811
812
813
814
815
816
# File 'lib/aws-sdk-servicequotas/types.rb', line 808

class ListServiceQuotasRequest < Struct.new(
  :service_code,
  :next_token,
  :max_results,
  :quota_code,
  :quota_applied_at_level)
  SENSITIVE = []
  include Aws::Structure
end

#service_code ⇒ String

Specifies the service identifier. To find the service code value for an Amazon Web Services service, use the ListServices operation.

Returns:

  • (String)


808
809
810
811
812
813
814
815
816
# File 'lib/aws-sdk-servicequotas/types.rb', line 808

class ListServiceQuotasRequest < Struct.new(
  :service_code,
  :next_token,
  :max_results,
  :quota_code,
  :quota_applied_at_level)
  SENSITIVE = []
  include Aws::Structure
end