Class: Aws::ServiceQuotas::Types::ListServiceQuotasResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceQuotas::Types::ListServiceQuotasResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicequotas/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If present, indicates that more output is available than is included in the current response.
-
#quotas ⇒ Array<Types::ServiceQuota>
Information about the quotas.
Instance Attribute Details
#next_token ⇒ String
If present, indicates that more output is available than is included
in the current response. Use this value in the NextToken request
parameter in a subsequent call to the operation to get the next part
of the output. You should repeat this until the NextToken response
element comes back as null.
832 833 834 835 836 837 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 832 class ListServiceQuotasResponse < Struct.new( :next_token, :quotas) SENSITIVE = [] include Aws::Structure end |
#quotas ⇒ Array<Types::ServiceQuota>
Information about the quotas.
832 833 834 835 836 837 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 832 class ListServiceQuotasResponse < Struct.new( :next_token, :quotas) SENSITIVE = [] include Aws::Structure end |