Class: Aws::ServiceQuotas::Types::ListTagsForResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceQuotas::Types::ListTagsForResourceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicequotas/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the applied quota for which you want to list tags.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the applied quota for which you want to list tags. You can get this information by using the Service Quotas console, or by listing the quotas using the
- list-service-quotas][1
-
CLI command or the [ListServiceQuotas]
Amazon Web Services API operation.
[1]: docs.aws.amazon.com/cli/latest/reference/service-quotas/list-service-quotas.html [2]: docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListServiceQuotas.html
908 909 910 911 912 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 908 class ListTagsForResourceRequest < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |