Class: Aws::ServiceQuotas::Types::ListTagsForResourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceQuotas::Types::ListTagsForResourceResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicequotas/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tags ⇒ Array<Types::Tag>
A complex data type that contains zero or more tag elements.
Instance Attribute Details
#tags ⇒ Array<Types::Tag>
A complex data type that contains zero or more tag elements.
920 921 922 923 924 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 920 class ListTagsForResourceResponse < Struct.new( :tags) SENSITIVE = [] include Aws::Structure end |