Class: Aws::ServiceQuotas::Types::ServiceQuota

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-servicequotas/types.rb

Overview

Information about a quota.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#adjustable ⇒ Boolean

Indicates whether the quota value can be increased.

Returns:

  • (Boolean)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The quota description.

Returns:

  • (String)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#error_reason ⇒ Types::ErrorReason

The error code and error reason.

Returns:



1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#global_quota ⇒ Boolean

Indicates whether the quota is global.

Returns:

  • (Boolean)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#period ⇒ Types::QuotaPeriod

The period of time.

Returns:



1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#quota_applied_at_level ⇒ String

Filters the response to return applied quota values for the ACCOUNT, RESOURCE, or ALL levels. ACCOUNT is the default.

Returns:

  • (String)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#quota_arn ⇒ String

The Amazon Resource Name (ARN) of the quota.

Returns:

  • (String)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#quota_code ⇒ String

Specifies the quota identifier. To find the quota code for a specific quota, use the ListServiceQuotas operation, and look for the QuotaCode response in the output for the quota you want.

Returns:

  • (String)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#quota_context ⇒ Types::QuotaContextInfo

The context for this service quota.



1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#quota_name ⇒ String

Specifies the quota name.

Returns:

  • (String)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#service_code ⇒ String

Specifies the service identifier. To find the service code value for an Amazon Web Services service, use the ListServices operation.

Returns:

  • (String)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#service_name ⇒ String

Specifies the service name.

Returns:

  • (String)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#unit ⇒ String

The unit of measurement.

Returns:

  • (String)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#usage_metric ⇒ Types::MetricInfo

Information about the measurement.

Returns:



1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#value ⇒ Float

The quota value.

Returns:

  • (Float)


1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/aws-sdk-servicequotas/types.rb', line 1519

class ServiceQuota < Struct.new(
  :service_code,
  :service_name,
  :quota_arn,
  :quota_code,
  :quota_name,
  :value,
  :unit,
  :adjustable,
  :global_quota,
  :usage_metric,
  :period,
  :error_reason,
  :quota_applied_at_level,
  :quota_context,
  :description)
  SENSITIVE = []
  include Aws::Structure
end