Class: Aws::ServiceQuotas::Types::ServiceQuotaIncreaseRequestInTemplate

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-servicequotas/types.rb

Overview

Information about a quota increase request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_region ⇒ String

The Amazon Web Services Region.

Returns:

  • (String)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
# File 'lib/aws-sdk-servicequotas/types.rb', line 1578

class ServiceQuotaIncreaseRequestInTemplate < Struct.new(
  :service_code,
  :service_name,
  :quota_code,
  :quota_name,
  :desired_value,
  :aws_region,
  :unit,
  :global_quota)
  SENSITIVE = []
  include Aws::Structure
end

#desired_value ⇒ Float

The new, increased value of the quota.

Returns:

  • (Float)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
# File 'lib/aws-sdk-servicequotas/types.rb', line 1578

class ServiceQuotaIncreaseRequestInTemplate < Struct.new(
  :service_code,
  :service_name,
  :quota_code,
  :quota_name,
  :desired_value,
  :aws_region,
  :unit,
  :global_quota)
  SENSITIVE = []
  include Aws::Structure
end

#global_quota ⇒ Boolean

Indicates whether the quota is global.

Returns:

  • (Boolean)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
# File 'lib/aws-sdk-servicequotas/types.rb', line 1578

class ServiceQuotaIncreaseRequestInTemplate < Struct.new(
  :service_code,
  :service_name,
  :quota_code,
  :quota_name,
  :desired_value,
  :aws_region,
  :unit,
  :global_quota)
  SENSITIVE = []
  include Aws::Structure
end

#quota_code ⇒ String

Specifies the quota identifier. To find the quota code for a specific quota, use the ListServiceQuotas operation, and look for the QuotaCode response in the output for the quota you want.

Returns:

  • (String)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
# File 'lib/aws-sdk-servicequotas/types.rb', line 1578

class ServiceQuotaIncreaseRequestInTemplate < Struct.new(
  :service_code,
  :service_name,
  :quota_code,
  :quota_name,
  :desired_value,
  :aws_region,
  :unit,
  :global_quota)
  SENSITIVE = []
  include Aws::Structure
end

#quota_name ⇒ String

Specifies the quota name.

Returns:

  • (String)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
# File 'lib/aws-sdk-servicequotas/types.rb', line 1578

class ServiceQuotaIncreaseRequestInTemplate < Struct.new(
  :service_code,
  :service_name,
  :quota_code,
  :quota_name,
  :desired_value,
  :aws_region,
  :unit,
  :global_quota)
  SENSITIVE = []
  include Aws::Structure
end

#service_code ⇒ String

Specifies the service identifier. To find the service code value for an Amazon Web Services service, use the ListServices operation.

Returns:

  • (String)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
# File 'lib/aws-sdk-servicequotas/types.rb', line 1578

class ServiceQuotaIncreaseRequestInTemplate < Struct.new(
  :service_code,
  :service_name,
  :quota_code,
  :quota_name,
  :desired_value,
  :aws_region,
  :unit,
  :global_quota)
  SENSITIVE = []
  include Aws::Structure
end

#service_name ⇒ String

Specifies the service name.

Returns:

  • (String)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
# File 'lib/aws-sdk-servicequotas/types.rb', line 1578

class ServiceQuotaIncreaseRequestInTemplate < Struct.new(
  :service_code,
  :service_name,
  :quota_code,
  :quota_name,
  :desired_value,
  :aws_region,
  :unit,
  :global_quota)
  SENSITIVE = []
  include Aws::Structure
end

#unit ⇒ String

The unit of measurement.

Returns:

  • (String)


1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
# File 'lib/aws-sdk-servicequotas/types.rb', line 1578

class ServiceQuotaIncreaseRequestInTemplate < Struct.new(
  :service_code,
  :service_name,
  :quota_code,
  :quota_name,
  :desired_value,
  :aws_region,
  :unit,
  :global_quota)
  SENSITIVE = []
  include Aws::Structure
end