Class: Aws::ServiceQuotas::Types::TagResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-servicequotas/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) for the applied quota. You can get this information by using the Service Quotas console, or by listing the quotas using the [list-service-quotas] CLI command or the

ListServiceQuotas][2

Amazon Web Services API operation.

[1]: docs.aws.amazon.com/cli/latest/reference/service-quotas/list-service-quotas.html [2]: docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListServiceQuotas.html

Returns:

  • (String)


1730
1731
1732
1733
1734
1735
# File 'lib/aws-sdk-servicequotas/types.rb', line 1730

class TagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The tags that you want to add to the resource.

Returns:



1730
1731
1732
1733
1734
1735
# File 'lib/aws-sdk-servicequotas/types.rb', line 1730

class TagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end