Class: Aws::ServiceQuotas::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ServiceQuotas::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-servicequotas/client.rb
Overview
An API client for ServiceQuotas. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ServiceQuotas::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_service_quota_template(params = {}) ⇒ Struct
Associates your quota request template with your organization.
-
#create_support_case(params = {}) ⇒ Struct
Creates a Support case for an existing quota increase request.
-
#delete_service_quota_increase_request_from_template(params = {}) ⇒ Struct
Deletes the quota increase request for the specified quota from your quota request template.
-
#disassociate_service_quota_template(params = {}) ⇒ Struct
Disables your quota request template.
-
#get_association_for_service_quota_template(params = {}) ⇒ Types::GetAssociationForServiceQuotaTemplateResponse
Retrieves the status of the association for the quota request template.
-
#get_auto_management_configuration(params = {}) ⇒ Types::GetAutoManagementConfigurationResponse
Retrieves information about your [Service Quotas Automatic Management] configuration.
-
#get_aws_default_service_quota(params = {}) ⇒ Types::GetAWSDefaultServiceQuotaResponse
Retrieves the default value for the specified quota.
-
#get_quota_utilization_report(params = {}) ⇒ Types::GetQuotaUtilizationReportResponse
Retrieves the quota utilization report for your Amazon Web Services account.
-
#get_requested_service_quota_change(params = {}) ⇒ Types::GetRequestedServiceQuotaChangeResponse
Retrieves information about the specified quota increase request.
-
#get_service_quota(params = {}) ⇒ Types::GetServiceQuotaResponse
Retrieves the applied quota value for the specified account-level or resource-level quota.
-
#get_service_quota_increase_request_from_template(params = {}) ⇒ Types::GetServiceQuotaIncreaseRequestFromTemplateResponse
Retrieves information about the specified quota increase request in your quota request template.
-
#list_aws_default_service_quotas(params = {}) ⇒ Types::ListAWSDefaultServiceQuotasResponse
Lists the default values for the quotas for the specified Amazon Web Services service.
-
#list_requested_service_quota_change_history(params = {}) ⇒ Types::ListRequestedServiceQuotaChangeHistoryResponse
Retrieves the quota increase requests for the specified Amazon Web Services service.
-
#list_requested_service_quota_change_history_by_quota(params = {}) ⇒ Types::ListRequestedServiceQuotaChangeHistoryByQuotaResponse
Retrieves the quota increase requests for the specified quota.
-
#list_service_quota_increase_requests_in_template(params = {}) ⇒ Types::ListServiceQuotaIncreaseRequestsInTemplateResponse
Lists the quota increase requests in the specified quota request template.
-
#list_service_quotas(params = {}) ⇒ Types::ListServiceQuotasResponse
Lists the applied quota values for the specified Amazon Web Services service.
-
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists the names and codes for the Amazon Web Services services integrated with Service Quotas.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags assigned to the specified applied quota.
-
#put_service_quota_increase_request_into_template(params = {}) ⇒ Types::PutServiceQuotaIncreaseRequestIntoTemplateResponse
Adds a quota increase request to your quota request template.
-
#request_service_quota_increase(params = {}) ⇒ Types::RequestServiceQuotaIncreaseResponse
Submits a quota increase request for the specified quota at the account or resource level.
-
#start_auto_management(params = {}) ⇒ Struct
Starts [Service Quotas Automatic Management] for an Amazon Web Services account, including notification preferences and excluded quotas configurations.
-
#start_quota_utilization_report(params = {}) ⇒ Types::StartQuotaUtilizationReportResponse
Initiates the generation of a quota utilization report for your Amazon Web Services account.
-
#stop_auto_management(params = {}) ⇒ Struct
Stops [Service Quotas Automatic Management] for an Amazon Web Services account and removes all associated configurations.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified applied quota.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified applied quota.
-
#update_auto_management(params = {}) ⇒ Struct
Updates your [Service Quotas Automatic Management] configuration, including notification preferences and excluded quotas.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1838 1839 1840 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1838 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1841 1842 1843 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1841 def errors_module Errors end |
Instance Method Details
#associate_service_quota_template(params = {}) ⇒ Struct
Associates your quota request template with your organization. When a new Amazon Web Services account is created in your organization, the quota increase requests in the template are automatically applied to the account. You can add a quota increase request for any adjustable quota to your template.
496 497 498 499 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 496 def associate_service_quota_template(params = {}, = {}) req = build_request(:associate_service_quota_template, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1811 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ServiceQuotas') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-servicequotas' context[:gem_version] = '1.73.0' Seahorse::Client::Request.new(handlers, context) end |
#create_support_case(params = {}) ⇒ Struct
Creates a Support case for an existing quota increase request. This call only creates a Support case if the request has a ‘Pending` status.
521 522 523 524 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 521 def create_support_case(params = {}, = {}) req = build_request(:create_support_case, params) req.send_request() end |
#delete_service_quota_increase_request_from_template(params = {}) ⇒ Struct
Deletes the quota increase request for the specified quota from your quota request template.
556 557 558 559 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 556 def delete_service_quota_increase_request_from_template(params = {}, = {}) req = build_request(:delete_service_quota_increase_request_from_template, params) req.send_request() end |
#disassociate_service_quota_template(params = {}) ⇒ Struct
Disables your quota request template. After a template is disabled, the quota increase requests in the template are not applied to new Amazon Web Services accounts in your organization. Disabling a quota request template does not apply its quota increase requests.
572 573 574 575 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 572 def disassociate_service_quota_template(params = {}, = {}) req = build_request(:disassociate_service_quota_template, params) req.send_request() end |
#get_association_for_service_quota_template(params = {}) ⇒ Types::GetAssociationForServiceQuotaTemplateResponse
Retrieves the status of the association for the quota request template.
650 651 652 653 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 650 def get_association_for_service_quota_template(params = {}, = {}) req = build_request(:get_association_for_service_quota_template, params) req.send_request() end |
#get_auto_management_configuration(params = {}) ⇒ Types::GetAutoManagementConfigurationResponse
Retrieves information about your [Service Quotas Automatic Management] configuration. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
[1]: docs.aws.amazon.com/servicequotas/latest/userguide/automatic-management.html
687 688 689 690 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 687 def get_auto_management_configuration(params = {}, = {}) req = build_request(:get_auto_management_configuration, params) req.send_request() end |
#get_aws_default_service_quota(params = {}) ⇒ Types::GetAWSDefaultServiceQuotaResponse
Retrieves the default value for the specified quota. The default value does not reflect any quota increases.
630 631 632 633 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 630 def get_aws_default_service_quota(params = {}, = {}) req = build_request(:get_aws_default_service_quota, params) req.send_request() end |
#get_quota_utilization_report(params = {}) ⇒ Types::GetQuotaUtilizationReportResponse
Retrieves the quota utilization report for your Amazon Web Services account. This operation returns paginated results showing your quota usage across all Amazon Web Services services, sorted by utilization percentage in descending order (highest utilization first).
You must first initiate a report using the ‘StartQuotaUtilizationReport` operation. The report generation process is asynchronous and may take several seconds to complete. Poll this operation periodically to check the status and retrieve results when the report is ready.
Each report contains up to 1,000 quota records per page. Use the ‘NextToken` parameter to retrieve additional pages of results. Reports are automatically deleted after 15 minutes.
763 764 765 766 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 763 def get_quota_utilization_report(params = {}, = {}) req = build_request(:get_quota_utilization_report, params) req.send_request() end |
#get_requested_service_quota_change(params = {}) ⇒ Types::GetRequestedServiceQuotaChangeResponse
Retrieves information about the specified quota increase request.
809 810 811 812 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 809 def get_requested_service_quota_change(params = {}, = {}) req = build_request(:get_requested_service_quota_change, params) req.send_request() end |
#get_service_quota(params = {}) ⇒ Types::GetServiceQuotaResponse
Retrieves the applied quota value for the specified account-level or resource-level quota. For some quotas, only the default values are available. If the applied quota value is not available for a quota, the quota is not retrieved.
873 874 875 876 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 873 def get_service_quota(params = {}, = {}) req = build_request(:get_service_quota, params) req.send_request() end |
#get_service_quota_increase_request_from_template(params = {}) ⇒ Types::GetServiceQuotaIncreaseRequestFromTemplateResponse
Retrieves information about the specified quota increase request in your quota request template.
921 922 923 924 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 921 def get_service_quota_increase_request_from_template(params = {}, = {}) req = build_request(:get_service_quota_increase_request_from_template, params) req.send_request() end |
#list_aws_default_service_quotas(params = {}) ⇒ Types::ListAWSDefaultServiceQuotasResponse
Lists the default values for the quotas for the specified Amazon Web Services service. A default value does not reflect any quota increases.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1003 1004 1005 1006 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1003 def list_aws_default_service_quotas(params = {}, = {}) req = build_request(:list_aws_default_service_quotas, params) req.send_request() end |
#list_requested_service_quota_change_history(params = {}) ⇒ Types::ListRequestedServiceQuotaChangeHistoryResponse
Retrieves the quota increase requests for the specified Amazon Web Services service. Filter responses to return quota requests at either the account level, resource level, or all levels. Responses include any open or closed requests within 90 days.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1092 1093 1094 1095 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1092 def list_requested_service_quota_change_history(params = {}, = {}) req = build_request(:list_requested_service_quota_change_history, params) req.send_request() end |
#list_requested_service_quota_change_history_by_quota(params = {}) ⇒ Types::ListRequestedServiceQuotaChangeHistoryByQuotaResponse
Retrieves the quota increase requests for the specified quota. Filter responses to return quota requests at either the account level, resource level, or all levels.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1186 1187 1188 1189 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1186 def list_requested_service_quota_change_history_by_quota(params = {}, = {}) req = build_request(:list_requested_service_quota_change_history_by_quota, params) req.send_request() end |
#list_service_quota_increase_requests_in_template(params = {}) ⇒ Types::ListServiceQuotaIncreaseRequestsInTemplateResponse
Lists the quota increase requests in the specified quota request template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1257 1258 1259 1260 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1257 def list_service_quota_increase_requests_in_template(params = {}, = {}) req = build_request(:list_service_quota_increase_requests_in_template, params) req.send_request() end |
#list_service_quotas(params = {}) ⇒ Types::ListServiceQuotasResponse
Lists the applied quota values for the specified Amazon Web Services service. For some quotas, only the default values are available. If the applied quota value is not available for a quota, the quota is not retrieved. Filter responses to return applied quota values at either the account level, resource level, or all levels.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1352 1353 1354 1355 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1352 def list_service_quotas(params = {}, = {}) req = build_request(:list_service_quotas, params) req.send_request() end |
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists the names and codes for the Amazon Web Services services integrated with Service Quotas.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1407 1408 1409 1410 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1407 def list_services(params = {}, = {}) req = build_request(:list_services, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags assigned to the specified applied quota.
1446 1447 1448 1449 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1446 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_service_quota_increase_request_into_template(params = {}) ⇒ Types::PutServiceQuotaIncreaseRequestIntoTemplateResponse
Adds a quota increase request to your quota request template.
1497 1498 1499 1500 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1497 def put_service_quota_increase_request_into_template(params = {}, = {}) req = build_request(:put_service_quota_increase_request_into_template, params) req.send_request() end |
#request_service_quota_increase(params = {}) ⇒ Types::RequestServiceQuotaIncreaseResponse
Submits a quota increase request for the specified quota at the account or resource level.
1571 1572 1573 1574 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1571 def request_service_quota_increase(params = {}, = {}) req = build_request(:request_service_quota_increase, params) req.send_request() end |
#start_auto_management(params = {}) ⇒ Struct
Starts [Service Quotas Automatic Management] for an Amazon Web Services account, including notification preferences and excluded quotas configurations. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
[1]: docs.aws.amazon.com/servicequotas/latest/userguide/automatic-management.html
1626 1627 1628 1629 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1626 def start_auto_management(params = {}, = {}) req = build_request(:start_auto_management, params) req.send_request() end |
#start_quota_utilization_report(params = {}) ⇒ Types::StartQuotaUtilizationReportResponse
Initiates the generation of a quota utilization report for your Amazon Web Services account. This asynchronous operation analyzes your quota usage across all Amazon Web Services services and returns a unique report identifier that you can use to retrieve the results.
The report generation process may take several seconds to complete, depending on the number of quotas in your account. Use the ‘GetQuotaUtilizationReport` operation to check the status and retrieve the results when the report is ready.
1657 1658 1659 1660 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1657 def start_quota_utilization_report(params = {}, = {}) req = build_request(:start_quota_utilization_report, params) req.send_request() end |
#stop_auto_management(params = {}) ⇒ Struct
Stops [Service Quotas Automatic Management] for an Amazon Web Services account and removes all associated configurations. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
[1]: docs.aws.amazon.com/servicequotas/latest/userguide/automatic-management.html
1677 1678 1679 1680 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1677 def stop_auto_management(params = {}, = {}) req = build_request(:stop_auto_management, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified applied quota. You can include one or more tags to add to the quota.
1717 1718 1719 1720 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1717 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified applied quota. You can specify one or more tags to remove.
1753 1754 1755 1756 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1753 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_auto_management(params = {}) ⇒ Struct
Updates your [Service Quotas Automatic Management] configuration, including notification preferences and excluded quotas. Automatic Management monitors your Service Quotas utilization and notifies you before you run out of your allocated quotas.
[1]: docs.aws.amazon.com/servicequotas/latest/userguide/automatic-management.html
1802 1803 1804 1805 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1802 def update_auto_management(params = {}, = {}) req = build_request(:update_auto_management, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1831 1832 1833 |
# File 'lib/aws-sdk-servicequotas/client.rb', line 1831 def waiter_names [] end |