Class: Aws::ServiceQuotas::Types::GetQuotaUtilizationReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceQuotas::Types::GetQuotaUtilizationReportRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicequotas/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
A token that indicates the next page of results to retrieve.
-
#report_id ⇒ String
The unique identifier for the quota utilization report.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return per page. The default value is 1,000 and the maximum allowed value is 1,000.
274 275 276 277 278 279 280 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 274 class GetQuotaUtilizationReportRequest < Struct.new( :report_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates the next page of results to retrieve. This token is returned in the response when there are more results available. Omit this parameter for the first request.
274 275 276 277 278 279 280 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 274 class GetQuotaUtilizationReportRequest < Struct.new( :report_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#report_id ⇒ String
The unique identifier for the quota utilization report. This identifier is returned by the ‘StartQuotaUtilizationReport` operation.
274 275 276 277 278 279 280 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 274 class GetQuotaUtilizationReportRequest < Struct.new( :report_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |