Class: Aws::ServiceQuotas::Types::ListServiceQuotasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceQuotas::Types::ListServiceQuotasRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicequotas/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Specifies the maximum number of results that you want included on each page of the response.
-
#next_token ⇒ String
Specifies a value for receiving additional results after you receive a
NextTokenresponse in a previous request. -
#quota_applied_at_level ⇒ String
Filters the response to return applied quota values for the
ACCOUNT,RESOURCE, orALLlevels. -
#quota_code ⇒ String
Specifies the quota identifier.
-
#service_code ⇒ String
Specifies the service identifier.
Instance Attribute Details
#max_results ⇒ Integer
Specifies the maximum number of results that you want included on
each page of the response. If you do not include this parameter, it
defaults to a value appropriate to the operation. If additional
items exist beyond those included in the current response, the
NextToken response element is present and has a value (is not
null). Include that value as the NextToken request parameter in
the next call to the operation to get the next part of the results.
NextToken after
every operation to ensure that you receive all of the results.
808 809 810 811 812 813 814 815 816 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 808 class ListServiceQuotasRequest < Struct.new( :service_code, :next_token, :max_results, :quota_code, :quota_applied_at_level) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies a value for receiving additional results after you receive
a NextToken response in a previous request. A NextToken response
indicates that more output is available. Set this parameter to the
value of the previous call's NextToken response to indicate where
the output should continue from.
808 809 810 811 812 813 814 815 816 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 808 class ListServiceQuotasRequest < Struct.new( :service_code, :next_token, :max_results, :quota_code, :quota_applied_at_level) SENSITIVE = [] include Aws::Structure end |
#quota_applied_at_level ⇒ String
Filters the response to return applied quota values for the
ACCOUNT, RESOURCE, or ALL levels. ACCOUNT is the default.
808 809 810 811 812 813 814 815 816 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 808 class ListServiceQuotasRequest < Struct.new( :service_code, :next_token, :max_results, :quota_code, :quota_applied_at_level) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
Specifies the quota identifier. To find the quota code for a
specific quota, use the ListServiceQuotas operation, and look for
the QuotaCode response in the output for the quota you want.
808 809 810 811 812 813 814 815 816 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 808 class ListServiceQuotasRequest < Struct.new( :service_code, :next_token, :max_results, :quota_code, :quota_applied_at_level) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
Specifies the service identifier. To find the service code value for an Amazon Web Services service, use the ListServices operation.
808 809 810 811 812 813 814 815 816 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 808 class ListServiceQuotasRequest < Struct.new( :service_code, :next_token, :max_results, :quota_code, :quota_applied_at_level) SENSITIVE = [] include Aws::Structure end |