Class: Aws::ServiceQuotas::Types::StartQuotaUtilizationReportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceQuotas::Types::StartQuotaUtilizationReportResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicequotas/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
An optional message providing additional information about the report generation status.
-
#report_id ⇒ String
A unique identifier for the quota utilization report.
-
#status ⇒ String
The current status of the report generation.
Instance Attribute Details
#message ⇒ String
An optional message providing additional information about the report generation status. This field may contain details about the report initiation or indicate if an existing recent report is being reused.
1672 1673 1674 1675 1676 1677 1678 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 1672 class StartQuotaUtilizationReportResponse < Struct.new( :report_id, :status, :message) SENSITIVE = [] include Aws::Structure end |
#report_id ⇒ String
A unique identifier for the quota utilization report. Use this
identifier with the GetQuotaUtilizationReport operation to
retrieve the report results.
1672 1673 1674 1675 1676 1677 1678 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 1672 class StartQuotaUtilizationReportResponse < Struct.new( :report_id, :status, :message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the report generation. The status will be
PENDING when the report is first initiated.
1672 1673 1674 1675 1676 1677 1678 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 1672 class StartQuotaUtilizationReportResponse < Struct.new( :report_id, :status, :message) SENSITIVE = [] include Aws::Structure end |