Class: Aws::ServiceQuotas::Types::UntagResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ServiceQuotas::Types::UntagResourceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-servicequotas/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the applied quota that you want to untag.
-
#tag_keys ⇒ Array<String>
The keys of the tags that you want to remove from the resource.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the applied quota that you want to untag. You can get this information by using the Service Quotas console, or by listing the quotas using the [list-service-quotas] CLI command or the [ListServiceQuotas] Amazon Web Services API operation.
[1]: docs.aws.amazon.com/cli/latest/reference/service-quotas/list-service-quotas.html [2]: docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListServiceQuotas.html
1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 1807 class UntagResourceRequest < Struct.new( :resource_arn, :tag_keys) SENSITIVE = [] include Aws::Structure end |
#tag_keys ⇒ Array<String>
The keys of the tags that you want to remove from the resource.
1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-servicequotas/types.rb', line 1807 class UntagResourceRequest < Struct.new( :resource_arn, :tag_keys) SENSITIVE = [] include Aws::Structure end |